<?php
/*
Plugin Name: Google Chrome Frame for WordPress
Version: 3.0
Plugin URI: http://www.seodenver.com/google-chrome-frame-plugin/
Description: Adds Google Chrome Frame compatibility to your WordPress blog.
Author: Katz Web Services, Inc.
Author URI: http://www.katzwebservices.com/

Copyright 2009 Katz Web Services, Inc. (email: info@katzwebservices.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
/*
	Change Log:
	1.0 		Launch
	2.0 		Added full Chrome Frame capabilities
	3.0			Added version control

// Thanks to Michael Torbert and Joost de Valk for some code snippets!

*/



add_action('admin_menu', 'kws_chrome_frame_add_admin');

function kws_chrome_frame_add_admin() {
    add_options_page('Google Chrome Frame', 'Google Chrome Frame', 'administrator', 'google-chrome-frame', 'kws_chrome_frame_options_page');  
}

add_filter( 'plugin_action_links', 'kws_chrome_frame_add_action_link', 10, 2 );

function kws_chrome_frame_add_action_link( $links, $file ) {
	static $this_plugin;
	 if( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
	if ( $file == $this_plugin ) {
		$settings_link = '<a href="' . admin_url( 'options-general.php?page=google-chrome-frame' ) . '">' . __('Settings') . '</a>';
		array_unshift( $links, $settings_link ); // before other links
	}
	return $links;
}

function kws_chrome_frame_options_page() {
	?>
	<div class="wrap">
	<h2>Google Chrome Frame for WordPress</h2>
	<div class="postbox-container" style="width:70%;">
					<div class="metabox-holder">	
						<div class="meta-box-sortables">
							<form action="options.php" method="post">
								<?php wp_nonce_field('update-options'); ?>
								
								<?php 
								$js = $meta = $version = '';
								if(get_option('google-chrome-meta')) { $meta = 'checked="1"'; }
								if(get_option('google-chrome-javascript')) { $js = 'checked="1"'; }
								$versions = get_option('google-chrome-version');
								if(!$versions) { $versions = array('all'); }
								if(!is_array($versions)) {
									$versions = array($versions);
								}
								$all = $ie8= $ie7 = $ie6=$ie5 = '';
								foreach($versions as $version) {
									switch($version) {
										case 'IE': $all .= 'checked="checked"'; break;
										case 'IE 8': $ie8 .= 'checked="checked"'; break;
										case 'IE 7': $ie7 .= 'checked="checked"'; break;
										case 'IE 6': $ie6 .= 'checked="checked"'; break;
										case 'IE 5': $ie5 .= 'checked="checked"'; break;
									}
								}
								
								$rows[] = array(
										'id' => 'google-chrome-meta',
										'label' => 'Add Google Chrome Frame code automatically to website',
										'desc' => 'Adds the following code to the head:<br /><code>&lt;meta http-equiv=&quot;X-UA-Compatible&quot; content=&quot;chrome=1&quot; /&gt;</code>',
										'content' => "<input type='checkbox' name='google-chrome-meta' id='google-chrome-meta' $meta />"
									);
									
								$rows[] = array(
										'id' => 'google-chrome-javascript',
										'label' => 'Check whether user has Chrome Frame, and prompt them to install it if not',
										'content' => "<input type='checkbox' name='google-chrome-javascript' id='google-chrome-javascript' $js />",
										'desc' => 'Adds the following code to the head:<br /><code>&lt;!--[if IE]&gt;&lt;script type=&quot;text/javascript&quot; src=&quot;http://ajax.googleapis.com/ajax/libs/chrome-frame/1/CFInstall.min.js&quot;&gt;&lt;/script&gt;&lt;![endif]--&gt;</code>'
									);
								
								$rows[] = array(
										'id' => 'google-chrome-version',
										'label' => 'Select which versions of IE are affected:',
										'desc' => 'Adds conditional comments to selectively apply script',
										'content' => "
										<ul>
										<li><label for='google-chrome-version-all'><input type='checkbox' name='google-chrome-version[]' id='google-chrome-version-all' value='IE' $all /> Any IE Versions<br /><small>If you have this checked, you don't need to check the others, but you still can ;-)</small></label></li>
										<li><label for='google-chrome-version-ie8'><input type='checkbox' name='google-chrome-version[]' id='google-chrome-version-ie8' value='IE 8' $ie8 /> IE 8</label></li>
										<li><label for='google-chrome-version-ie7'><input type='checkbox' name='google-chrome-version[]' id='google-chrome-version-ie7' value='IE 7' $ie7 /> IE 7</label></li>
										<li><label for='google-chrome-version-ie6'><input type='checkbox' name='google-chrome-version[]' id='google-chrome-version-ie6' value='IE 6' $ie6 /> IE 6</label></li>
										<li><label for='google-chrome-version-ie5'><input type='checkbox' name='google-chrome-version[]' id='google-chrome-version-ie5' value='IE 5' $ie5 /> IE 5</label></li>
										</ul>
										"
									);
															
								if(get_option('google-chrome-javascript')) echo '<div class="updated fade"><p>Google recommends that you move your wp_head(); function call in your header.php file to the top of the <head> section.</p></div>'; ?>
								<?php kws_postbox('gcfsettings','Google Chrome Frame Settings', kws_form_table($rows)); ?>
								
								<input type="hidden" name="action" value="update" />
								<input type="hidden" name="page_options" value="google-chrome-meta,google-chrome-javascript,google-chrome-version" />
								<input type="hidden" name="action" value="update" />
								<p class="submit">
								<input type="submit" class="button-primary" name="save" value="<?php _e('Save Changes') ?>" />
								</p>
							</form>
						</div>
					</div>
				</div>
</div>
<?php
 
}

// THANKS JOOST!
function kws_form_table($rows) {
	$content = '<table class="form-table" width="100%">';
	foreach ($rows as $row) {
		$content .= '<tr><th valign="top" scope="row" style="width:50%">';
		if (isset($row['id']) && $row['id'] != '')
			$content .= '<label for="'.$row['id'].'" style="font-weight:bold;">'.$row['label'].':</label>';
		else
			$content .= $row['label'];
		if (isset($row['desc']) && $row['desc'] != '')
			$content .= '<br/><small>'.$row['desc'].'</small>';
		$content .= '</th><td valign="top">';
		$content .= $row['content'];
		$content .= '</td></tr>'; 
	}
	$content .= '</table>';
	return $content;
}

function kws_postbox($id, $title, $content) {
	?>
		<div id="<?php echo $id; ?>" class="postbox">
			<div class="handlediv" title="Click to toggle"><br /></div>
			<h3 class="hndle"><span><?php echo $title; ?></span></h3>
			<div class="inside">
				<?php echo $content; ?>
			</div>
		</div>
	<?php
}


if(get_option('google-chrome-meta')){
	add_action('wp_head','kws_google_chrome_meta');
}

if(get_option('google-chrome-javascript')){
	add_action('wp_head','kws_google_chrome_js');
}

function kws_google_chrome_meta(){
	echo "\n".'<meta http-equiv="X-UA-Compatible" content="chrome=1" />';
}

function kws_google_chrome_versions() {
	$versions = get_option('google-chrome-version');
	if(!$versions) { $versions = array('all'); }
	if(!is_array($versions)) {
		$versions = array($versions);
	}
	$all = $ie8= $ie7 = $ie6=$ie5 = '';
	$i = 0;
	if(sizeof($versions) > 1) { $combine = true; } else { $combine = false; }
	foreach($versions as $version) {
		if($combine) { $output .= '('.$version.')'; } else { $output .= $version; }
		$i++;
		if(isset($versions[$i])) {
			$output .= '|';
		} 
	}
	$output = '[if '.$output.']';//(IE 6)|(IE 7)]
	return $output;
}

function kws_google_chrome_js(){
	
	echo "\n".'<!--'.kws_google_chrome_versions().'><script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/chrome-frame/1/CFInstall.min.js"></script><![endif]-->'."\n";
}

?>